@@ -296,7 +296,7 @@ PTguiGen <- function(language="Norwegian", exeArgus=NULL, pathArgus="", maxNchoi
                        s(mt["Gauss"]),
                        tau
                      ), 
-                     'SimpleSingle'),
+                     'Gauss'),
         checkboxInput('protectZeros', mt["protectZeros"], TRUE),
         radioButtons('maxN',mt["maxN"],
                      maxNchoices, # c("1"=1,"2"=2,"3"=3,"4"=4,"5"=5,"6"=6,"7"=7,"8"=8,"9"=9,"10"=10)
